@@ -72,6 +72,13 @@ typedef unsigned char byte;
 #include <stdlib.h>
 #endif
 
+//Ajout
+#ifdef linux
+#include <locale.h>
+#include <langinfo.h>
+#include <iconv.h>
+#endif
+char * conversion_charset (char* s, char* from_charset, char* to_charset);
                                   /* protos fonctions speciales accents... */
 byte ToLower( byte c );
 byte ToUpper( byte c );
@@ -96,7 +103,7 @@ void TakePath  (char *path);
 /*------------------------------------------------------------------------*/
 /*             Ici seul endroit pour modifier le numero de version:       */
 /*                                                                        */
-            char *__Version__ ="1.2" ;
+            char *__Version__ ="1.3" ;
 /*                                                                        */
 /*------------------------------------------------------------------------*/
 
@@ -104,6 +111,7 @@ char dict_path[127] ;
 int myterm = 0     ;    /* translation terminal pour accents */
 long count = 0 ;
 
+char *charset;
 
 
 
@@ -112,11 +120,14 @@ long count = 0 ;
  *           Code...
  */
 
+
+
 main( int argc, char **argv )
 {
  char *dic,*term ;
-
-    if( argc < 2 )
+ char * entree, sortie[256];
+ 
+ if( argc < 2 )
         return usage();
 
 #ifdef MSDOS
@@ -146,18 +157,29 @@ main( int argc, char **argv )
         return   options( argv[1][1]  );
 
     mybanner();                               /* on dit bonjour...     */
-
-    while( --argc)                            /* Allez, roulez !       */
+	
+	
+	//recherche le nom de l'encodage de caractres utilis
+	setlocale(LC_ALL,"");
+	charset =nl_langinfo(CODESET);
+	
+	
+   
+	while( --argc)                            /* Allez, roulez !       */
     {
-        if( isjoker (argv[argc][0] ) )
-            lookall( argv[argc] );
+		//conversion de la chaine en ISO-8859-1
+		entree =  conversion_charset (argv[argc],charset,"ISO-8859-1");
+		 if( isjoker (entree[0] ) )
+            lookall( entree );
         else
-            lookfor( argv[argc] );
+            lookfor( entree );
     }
-
-    fprintf(stderr,"\nTrouv %ld mot%s\n",count, count > 1 ? "s" :"" );
-
-       return OK ;
+	
+	sprintf (sortie,"\nTrouv %ld mot%s\n",count, count > 1 ? "s" :"" );
+	fprintf (stderr,"%s",conversion_charset (sortie,"ISO-8859-1",charset));
+	free (entree);
+    
+	return OK ;
 }
 /*--------------------------------------------------------------------------*/
 
@@ -389,7 +411,7 @@ lookfor ( char *pattern )
         if( fmatch(sbuf,pattern) )
         {
             translate( buf ); /* gere terminaux....   */
-            printf("\t%s\n", beautify(buf) );
+            printf("\t%s\n",conversion_charset (beautify(buf),"ISO-8859-1",charset)  );
             count ++ ;
         }
     }
@@ -446,7 +468,7 @@ lookall ( char *pattern )
             { 
                 translate( buf ) ;
                 buf[0] = ToUpper( buf[0] ) ;  
-                printf("\t%s\n", beautify (buf) );
+            	printf("\t%s\n",conversion_charset (beautify(buf),"ISO-8859-1",charset)  );
                 count ++ ;
             } 
         }
@@ -543,6 +565,7 @@ beautify ( byte * str )
     }
 	
     sprintf(result, "%-30s %s", ville, code );
+//	return iconv_ (result,"ISO-8859-1",charset);
     return result ;
 }
 /*--------------------------------------------------------------------------*/
@@ -785,6 +808,50 @@ StrISO ( byte *str )
         ibm2iso( str++ );
     } 
 }
+
+/*-----------------------------------------------------------------------*/
+
+
+/*-----------------------------------------------------------------------*/
+/*
+*
+*  conversion_charset:  Convertit l'encodage d'une chaine de caractres 
+*                       donns  partir d'un encodage vers un autre
+*
+*/
+char * conversion_charset (char* s, char* from_charset, char* to_charset)
+{
+	    
+	   char* retval;
+	   char *tmp;
+	   int s_lng,tmp_lng;
+
+#ifdef linux
+        iconv_t cd ;
+		cd	= iconv_open(to_charset, from_charset);
+        if (cd != (iconv_t) (-1)) 
+		{
+			s_lng = strlen(s);
+			tmp_lng= 4 * 3 * s_lng;
+			tmp = (char *) malloc ((tmp_lng)* sizeof (char));
+			char *ptr = tmp;
+             if ((iconv(cd, &s, &s_lng, &ptr, &tmp_lng)) != (size_t) (-1))
+			 {
+				 *ptr=0;
+				 retval = strdup(tmp);
+				 free (tmp);
+			 }
+			 iconv_close(cd);
+        }
+#else
+		retval = strdup (s); 
+#endif
+        return retval;
+}
+
+
+
+
 /*-----------------------------------------------------------------------*/
 
 
